@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.3';
+our $VERSION = 'v0.3.0';
 
 
 
@@ -185,6 +185,17 @@ has log => (
 );
 
 
+sub check {
+    my ($self) = @_;
+
+    my $files = $self->css_files;
+
+    scalar(keys %$files) or
+        return $self->log->( error => "no aliases" );
+
+    return 1;
+}
+
 
 sub href {
     my ($self, $name, $file) = @_;
@@ -308,7 +319,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.2.3
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -328,6 +339,8 @@ version v0.2.3
       },
   );
 
+  $css->check or die "Something is wrong";
+
   ...
 
   print $css->deferred_link_html( qw[ jqui site ] );
@@ -346,8 +359,8 @@ to something like
   <link rel="preload" as="stylesheet" href="....">
 
 but this is not well supported by all web browsers. So a web page
-needs some JavaScript to handle this, as well as a C<noscript> block
-as a fallback.
+needs some L<JavaScript|https://github.com/filamentgroup/loadCSS>
+to handle this, as well as a C<noscript> block as a fallback.
 
 This module allows you to simplify the management of stylesheets for a
 web application, from development to production by
@@ -442,10 +455,8 @@ tools for that.
 This is a hash reference used internally to translate L</aliases>
 into the actual files or URLs.
 
-If files cannot be found, then it will throw an error, so calling this
-attribute in void context can be used to check for any errors:
-
-  eval { $css->css_files } or die "$@";
+If files cannot be found, then it will throw an error. (See
+L</check>).
 
 =head2 cdn_links
 
@@ -492,6 +503,8 @@ This defaults to the same value as L</defer_css>.
 This is the pathname of the F<cssrelpreload.js> file that will be
 embedded in the resulting code.
 
+The script comes from L<https://github.com/filamentgroup/loadCSS>.
+
 You do not need to modify this unless you want to use a different
 script from the one included with this module.
 
@@ -540,6 +553,16 @@ or even integrate this with your own logging system:
 
 =head1 METHODS
 
+=head2 check
+
+This method instantiates lazy attributes and performs some minimal
+checks on the data.  (This should be called instead of L</css_files>.)
+
+It will throw an error or return false (depending on L</log>) if there
+is something wrong.
+
+This was added in v0.3.0.
+
 =head2 href
 
   my $href = $css->href( $alias );
@@ -615,10 +638,16 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+Please report any bugs in F<cssrelpreload.js> to
+L<https://github.com/filamentgroup/loadCSS/issues>.
+
 =head1 AUTHOR
 
 Robert Rothenberg <rrwo@cpan.org>
 
+This module was developed from work for Science Photo Library
+L<https://www.sciencephoto.com>.
+
 F<reset.css> comes from L<http://meyerweb.com/eric/tools/css/reset/>.
 
 F<cssrelpreload.js> comes from L<https://github.com/filamentgroup/loadCSS/>.
